--- ices-0.2.2/libshout/sock.c	Sat Mar 18 04:57:48 2000
+++ ../ices-0.2.2/libshout/sock.c	Wed Jan 16 17:49:22 2002
@@ -31,7 +31,11 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <sys/types.h>
+
+#ifdef HAVE_SYS_POLL_H
 #include <sys/poll.h>
+#endif
+
 #include <ctype.h>
 
 #ifdef HAVE_UNISTD_H
@@ -129,7 +133,12 @@
 int sock_write_bytes(SOCKET sockfd, const char *buff, const int len)
 {
 	int wrote, res, polled;
+#ifdef HAVE_SYS_POLL_H
 	struct pollfd socks;
+#else
+	fd_set writefds;
+	struct timeval timeout;
+#endif
 
 	/* sanity check */
 	if (!buff) {
@@ -140,13 +149,23 @@
 		return SOCKET_ERROR;
 	}
 
+#ifdef HAVE_SYS_POLL_H
 	socks.fd = sockfd;
 	socks.events = POLLOUT;
+#else
+	FD_ZERO(&writefds);
+	FD_SET(sockfd, &writefds);
+	timeout.tv_sec  = 0;
+	timeout.tv_usec = 1000;
+#endif
 
 	wrote = 0;
 	while (wrote < len) {
+#ifdef HAVE_SYS_POLL_H
 		polled = poll(&socks, 1, 30000);
-
+#else
+		polled = select(sockfd+1, 0, &writefds, 0, &timeout);
+#endif
 		if ((polled == -1) && sock_recoverable(errno))
 			continue;
 		if (polled != 1)

